@@ -1,11 +1,11 @@
 package Net::Appliance::Session;
 {
-  $Net::Appliance::Session::VERSION = '4.131210';
+  $Net::Appliance::Session::VERSION = '4.140230';
 }
 
 use Moo;
 use Sub::Quote;
-use MooX::Types::MooseLike::Base qw(Bool Str HashRef InstanceOf);
+use MooX::Types::MooseLike::Base qw(Bool Int Str HashRef InstanceOf);
 use Net::CLI::Interact;
 
 with 'Net::Appliance::Session::Transport';
@@ -86,7 +86,6 @@ foreach my $slot (qw/
     host
     app
     add_library
-    timeout
 /) {
     has $slot => (
         is => 'ro',
@@ -96,6 +95,13 @@ foreach my $slot (qw/
     );
 }
 
+has 'timeout' => (
+    is => 'ro',
+    isa => Int,
+    required => 0,
+    predicate => 1,
+);
+
 has 'connect_options' => (
     is => 'ro',
     isa => HashRef,
@@ -162,7 +168,7 @@ Net::Appliance::Session - Run command-line sessions to network appliances
 
 =head1 VERSION
 
-version 4.131210
+version 4.140230
 
 =head1 SYNOPSIS
 
@@ -531,7 +537,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Oliver Gorwits.
+This software is copyright (c) 2014 by Oliver Gorwits.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
